define([
  //Overview
  './overview/index',
  //Agents
  './agents/index',
  //Settings
  './settings/index',
  //Management
  './management/index',
  //Dev-tools
  './dev-tools/devToolsCtrl',
  // Main
  './main/mainCtrl',
  //Discover
  './discover/discoverCtrl',
  //Security
  './security/index',
], function () {})
